
From: Robert Picco <Robert.Picco@hp.com>

I found a problem with HP NUMA configuration in 2.6.7-rc3-mm1.  The
node_online_map is incorrect because of actions taken by
reassign_cpu_only_nodes in arch/ia64/mm/discontig.c.  The mm1 patch which
changes the mempolicy for the init_task uses this invalid node_online_map
and eventually uses a non-existent node's zonelist when calling
__alloc_pages.  

The patch below takes care of this issue.  It puts the non-existent nodes
offline.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/ia64/mm/discontig.c |    3 +++
 1 files changed, 3 insertions(+)

diff -puN arch/ia64/mm/discontig.c~ia64-discontic-fix arch/ia64/mm/discontig.c
--- 25/arch/ia64/mm/discontig.c~ia64-discontic-fix	Thu Jun 10 13:40:26 2004
+++ 25-akpm/arch/ia64/mm/discontig.c	Thu Jun 10 13:40:26 2004
@@ -154,6 +154,9 @@ static void __init reassign_cpu_only_nod
 
 	memcpy(numa_slit, numa_slit_fix, sizeof (numa_slit));
 
+	for (i = nnode; i < numnodes; i++)
+		node_set_offline(i);
+
 	numnodes = nnode;
 
 	return;
_
